@@ -114,7 +114,7 @@ class ConfigurationService(object):
     def _reload(self):
         """ Reload models and configuration """
 
-        LOG.info('Reloading configuration')
+        LOG.debug('Reloading configuration')
         # create a new parser first (w/o overriding the original one)
         parser = cfgparse.ConfigParser()
 
